@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP::Client;
 use vars '$VERSION';
-$VERSION = '2.24';
+$VERSION = '2.25';
 
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
@@ -58,7 +58,11 @@ sub compileClient(@)
 
         if(UNIVERSAL::isa($ans, 'XML::LibXML::Node'))
         {   $ans = try { $decode->($ans) };
-            $trace->{decode_errors} = $@ if $@;
+            if($@)
+            {   $trace->{decode_errors} = $@;
+                my $fatal = $trace->{error} = $@->wasFatal;
+                $fatal->message($fatal->message->concat("decode error: ", 1));
+            }
 
             my $end = time;
             $trace->{decode_elapse} = $end - $trace->{transport_end};
